@@ -1,4 +1,4 @@
-from text_sensitivity.sensitivity import compare_accuracy, compare_precision, compare_recall
+from text_sensitivity.sensitivity import compare_accuracy, compare_precision, compare_recall, input_space_robustness, input_space_robustness
 from text_sensitivity.perturbation import Perturbation, OneToOnePerturbation, OneToManyPerturbation
 from text_sensitivity.data.random.string import (RandomString, RandomAscii, RandomDigits, RandomEmojis,
                                                  RandomLower, RandomPunctuation, RandomSpaces, RandomUpper,
@@ -7,6 +7,7 @@ from text_sensitivity.data.random.entity import (RandomAddress, RandomCity, Rand
                                                  RandomFirstName, RandomLastName, RandomName,
                                                  RandomEmail, RandomPhoneNumber, RandomPriceTag,
                                                  RandomYear, RandomMonth, RandomDay, RandomDayOfWeek,
-                                                 RandomCurrencySymbol, RandomCryptoCurrency)
+                                                 RandomCurrencySymbol, RandomCryptoCurrency, RandomLicensePlate)
+from text_sensitivity.data.generate import from_pattern, default_patterns
 
-__version__ = '0.1.10'
+__version__ = '0.2.0'
