@@ -9,7 +9,7 @@ from instancelib.labels.memory import MemoryLabelProvider
 
 from text_explainability.default import Readable
 
-from text_sensitivity.data.random.base import SeedMixin, CaseMixin
+from text_sensitivity.data.base import SeedMixin, CaseMixin
 from text_sensitivity.internationalization import get_locale, LOCALE_MAP
 
 
@@ -336,3 +336,13 @@ class RandomCryptoCurrency(RandomEntity):
                          providers=['currency'],
                          fn_name='cryptocurrency_name',
                          seed=seed)
+
+
+class RandomLicensePlate(RandomEntity):
+    def __init__(self,
+                 seed: int = 0):
+        """Generate random license plates for a given country."""
+        super().__init__(languages='en',
+                         providers=['automotive'],
+                         fn_name='license_plate',
+                         seed=seed)
