@@ -14,12 +14,12 @@ def to_lower() -> OneToOnePerturbation:
     return OneToOnePerturbation.from_function(str.lower, 'not_lower', 'lower')
 
 
-def repeat_n_times(n: int = 10, connector: Optional[str] = ' '):
-    """Repeat a string n times."""
+def repeat_k_times(k: int = 10, connector: Optional[str] = ' '):
+    """Repeat a string k times."""
     if connector is None:
         connector = ''
 
-    def repeat_n(string: str) -> str:
-        return connector.join([string] * n)
+    def repeat_k(string: str) -> str:
+        return connector.join([string] * k)
 
-    return OneToOnePerturbation.from_function(repeat_n, label_to='repeated')
+    return OneToOnePerturbation.from_function(repeat_k, label_to='repeated')
